Python bindings to the OpenStack Searchlight API
================================================

This is a client for OpenStack Searchlight API. There's a Python API
(the :mod:`searchlightclient` module), and a command-line script
(installed as :program:`openstack`).

Contents
--------

.. toctree::
   :maxdepth: 2

   contribute/index


Man Page
--------

.. toctree::
   :maxdepth: 1

   man/openstack
   man/search
